Translations
============

If you want to help to translate this software please join me on Transifex: `transifex.com/projects/p/django-wp-admin/ <https://www.transifex.com/projects/p/django-wp-admin/>`_

Here is a list of available translations.

English
-------

Source (default) language.

Polish
------

100% by me (Maciej 'barszcz' Marczewski)

